@@ -212,7 +212,7 @@ class TelegramObject(ContextInstanceMixin, metaclass=MetaTelegramObject):
         """
         if item in self.props:
             return self.props[item].get_value(self)
-        raise KeyError(item)
+        return self.values[item]
 
     def __setitem__(self, key: str, value: typing.Any) -> None:
         """
@@ -224,6 +224,7 @@ class TelegramObject(ContextInstanceMixin, metaclass=MetaTelegramObject):
         """
         if key in self.props:
             return self.props[key].set_value(self, value, self.conf.get('parent', None))
+        self.values[key] = value
         raise KeyError(key)
 
     def __contains__(self, item: str) -> bool:
